<?php
/**
 * Namespace Suprimentos\Logic\Util
 *
 * PHP version 5
 *
 * @category Php
 * @package  Suprimentos\Logic\Util
 * @author   joaocorte <joao.corte@tecfood.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */

namespace Suprimentos\Logic\Util;

use \Geral\Util\DateUtil;
use \Estoque\Util\Parametros;

/**
 * Class ValidaDatas
 *
 * @category Php
 * @package  Suprimentos\Logic\Util
 * @author   joaocorte <joao.corte@tecfood.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */

class DataUtilLogic {

    /**
     * Valida se a data final é maior que a data inicial
     *
     * @param String $datini
     * @param String $datfin
     *
     * @return null
     */
    public static function validaDtInicialMaiorDtFinal($datini, $datfin)
    {
        if ($datini != $datfin && DateUtil::retornaMenorData($datfin, $datini) == $datfin) {
            tk_abort(tk_get_message_by_name('msg_valida_dataInicialFinal'));
        }
    }

    public static function validaDtInicialMenorDtProcessamento($dtini){
        //Valida se DTINICIAL é maior que Data de Processamento
        $dtprocessamento = Parametros::getDataProcessamento();
        if ($dtprocessamento instanceof DateTime) {
            $dtprocessamento = $dtprocessamento->format('d/m/Y');
        }
        $menorData = DateUtil::retornaMenorData($dtini, $dtprocessamento);
        if ($menorData < $dtprocessamento) {
            tk_abort(
                tk_get_message_by_name(
                    'cmp03800_DtInicial_maiorigual_DtProcessa'
                )
            );
        }
    }

    //Valida se os campos DTINICIAL estão preenchidos
    public static function validaDtInicialPrenchida($dtinicial){
        if (empty($dtinicial)) {
            tk_abort(tk_get_message_by_name('msg_informar_datainicial'));
        }
    }

    //Valida se os campos DTFINAL estão preenchidos
    public static function validaDtFinalPrenchida($dtfinal){
        if (empty($dtfinal)) {
            tk_abort(tk_get_message_by_name('msg_informar_datafinal'));
        }
    }
}